# view.py
# Walker M. White (wmw2)
# October 19, 2012
"""View class/module for temperature converter

This is the VIEW for the temperature converter application.  The
view must layout all of the graphics components.

Note that the view does very little else.  Furthermore, it does not
even have a method to start up the application.  That is the job
of the controller."""
from kivy.uix.boxlayout import BoxLayout
from kivy.uix.textinput import TextInput
from kivy.uix.label import Label
from kivy.uix.widget import Widget

class TemperaturePanel(BoxLayout):
    _fahrenheit  = None  # Text input
    _centigrade = None  # Text input
    
    @property  # Getter only; immutable
    def fahrenheitField(self):
        """Text Input for the farenheit value"""
        return self._fahrenheit

    @property  # Getter only; immutable
    def centigradeField(self):
        """Text Input for the centigrade value"""
        return self._centigrade

    def __init__(self,**kw):
        super(TemperaturePanel,self).__init__(**kw)
        self.orientation = 'vertical'
        
        # Vertical spacing
        widget = Widget(size_hint=(1,0.35))
        self.add_widget(widget)
        
        content = BoxLayout(orientation='horizontal',size_hint=(1,0.3))
        self.add_widget(content)

        widget = Widget(size_hint=(1,0.35))
        self.add_widget(widget)
        
        # Horizontal Content
        # Space before
        widget = Widget(size_hint=(0.025,1))
        content.add_widget(widget)
        
        # Farenheit
        label = Label(text='farenheit',font_size=14,bold=True)
        label.size_hint = (0.225,1)
        content.add_widget(label)
        
        text = TextInput(multiline=False,font_size=14)
        text.size_hint = (0.2,1)
        text.padding_y = 20
        text.padding_x = 12
        content.add_widget(text)
        self._fahrenheit = text
        
        # Space between
        widget = Widget(size_hint=(0.05,1))
        content.add_widget(widget)

        # Centigrade
        label = Label(text='centigrade',font_size=14,bold=True)
        label.size_hint = (0.225,1)
        content.add_widget(label)
        
        text = TextInput(multiline=False,font_size=14)
        text.size_hint = (0.2,1)
        text.padding_y = 20
        text.padding_x = 12
        content.add_widget(text)
        self._centigrade = text

        # Space after
        widget = Widget(size_hint=(0.075,1))
        content.add_widget(widget)

